@@ -13,12 +13,12 @@ http://download.oracle.com/javase/6/docs/platform/serialization/spec/protocol.ht
 
 :authors: Volodymyr Buell, Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.3
+:version: 0.4.4
 :status: Alpha
 
 ..
 
-    Copyright 2021 Thomas Calmant
+    Copyright 2024 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -76,7 +76,7 @@ __all__ = ("JavaObjectMarshaller",)
 
 
 # Module version
-__version_info__ = (0, 4, 3)
+__version_info__ = (0, 4, 4)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -141,6 +141,9 @@ class JavaObjectMarshaller:
         if isinstance(obj, JavaArray):
             # Deserialized Java array
             self.write_array(obj)
+        elif isinstance(obj, JavaByteArray):
+            # Deserialized Java byte array
+            self.write_array(obj)
         elif isinstance(obj, JavaEnum):
             # Deserialized Java Enum
             self.write_enum(obj)
@@ -537,6 +540,8 @@ class JavaObjectMarshaller:
                 self.write_object(value)
             elif isinstance(value, JavaString):
                 self.write_string(value)
+            elif isinstance(value, JavaClass):
+                self.write_class(value)
             elif isinstance(value, (BYTES_TYPE, UNICODE_TYPE)):
                 self.write_blockdata(value)
             else:
