@@ -4,12 +4,12 @@ Definition of the beans used to represent the parsed objects
 
 :authors: Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.3
+:version: 0.4.4
 :status: Alpha
 
 ..
 
-    Copyright 2021 Thomas Calmant
+    Copyright 2024 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -26,18 +26,18 @@ Definition of the beans used to represent the parsed objects
 
 from __future__ import absolute_import
 
+import logging
 from enum import IntEnum
 from typing import Any, Dict, List, Optional, Set
-import logging
 
 from ..constants import ClassDescFlags, TypeCode
-from ..modifiedutf8 import decode_modified_utf8, byte_to_int
+from ..modifiedutf8 import byte_to_int, decode_modified_utf8
 from ..utils import UNICODE_TYPE
 
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 3)
+__version_info__ = (0, 4, 4)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
