@@ -5,12 +5,12 @@ See: https://github.com/frohoff/jdeserialize
 
 :authors: Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.3
+:version: 0.4.4
 :status: Alpha
 
 ..
 
-    Copyright 2021 Thomas Calmant
+    Copyright 2024 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -27,51 +27,50 @@ See: https://github.com/frohoff/jdeserialize
 
 from __future__ import absolute_import
 
-from typing import (
+import logging
+import os
+from typing import (  # pylint:disable=W0611
+    IO,
     Any,
     Callable,
     Dict,
-    IO,
     List,
     Optional,
-)  # pylint:disable=W0611
-import logging
-import os
+)
 
+from ..constants import (
+    PRIMITIVE_TYPES,
+    StreamConstants,
+    TerminalCode,
+    TypeCode,
+)
+from ..modifiedutf8 import (  # pylint:disable=W0611  # noqa: F401
+    decode_modified_utf8,
+)
 from . import api  # pylint:disable=W0611
 from .beans import (
-    ParsedJavaContent,
     BlockData,
-    JavaClassDesc,
-    JavaClass,
+    ClassDataType,
+    ClassDescType,
+    ExceptionRead,
+    ExceptionState,
+    FieldType,
     JavaArray,
+    JavaClass,
+    JavaClassDesc,
     JavaEnum,
     JavaField,
     JavaInstance,
     JavaString,
-    ExceptionState,
-    ExceptionRead,
-    ClassDescType,
-    FieldType,
-    ClassDataType,
+    ParsedJavaContent,
 )
 from .stream import DataStreamReader
 from .transformers import DefaultObjectTransformer
-from ..constants import (
-    StreamConstants,
-    TerminalCode,
-    TypeCode,
-    PRIMITIVE_TYPES,
-)
-
-from ..modifiedutf8 import (
-    decode_modified_utf8,
-)  # pylint:disable=W0611  # noqa: F401
 
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 3)
+__version_info__ = (0, 4, 4)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -80,7 +79,7 @@ __docformat__ = "restructuredtext en"
 # ------------------------------------------------------------------------------
 
 
-class JavaStreamParser:
+class JavaStreamParser(api.IJavaStreamParser):
     """
     Parses a Java stream
     """
