@@ -4,12 +4,12 @@ Defines the default object transformers
 
 :authors: Thomas Calmant
 :license: Apache License 2.0
-:version: 0.4.3
+:version: 0.4.4
 :status: Alpha
 
 ..
 
-    Copyright 2021 Thomas Calmant
+    Copyright 2024 Thomas Calmant
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -25,30 +25,30 @@ Defines the default object transformers
 """
 
 # Standard library
-from typing import List, Optional, Tuple
 import functools
+from typing import List, Optional, Tuple
 
 # Numpy (optional)
 try:
     import numpy
 except ImportError:
-    numpy = None
-
+    numpy = None  # type: ignore
 
 # Javaobj
-from .api import ObjectTransformer
-from .beans import (
-    JavaInstance,
-    JavaClassDesc,
-    BlockData,
-)  # pylint:disable=W0611
 from ..constants import TerminalCode, TypeCode
-from ..utils import to_bytes, log_error, log_debug, read_struct, read_string
+from ..utils import log_debug, log_error, read_string, read_struct, to_bytes
+from .api import IJavaStreamParser, ObjectTransformer
+from .beans import ( # pylint:disable=W0611
+    BlockData,
+    JavaClassDesc,
+    JavaInstance,
+)
+from .stream import DataStreamReader
 
 # ------------------------------------------------------------------------------
 
 # Module version
-__version_info__ = (0, 4, 3)
+__version_info__ = (0, 4, 4)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -183,7 +183,7 @@ class JavaLinkedHashMap(JavaMap):
     HANDLED_CLASSES = ("java.util.LinkedHashMap",)
 
     def load_from_blockdata(self, parser, reader, indent=0):
-        # type: (JavaStreamParser, DataStreamReader, int) -> bool
+        # type: (IJavaStreamParser, DataStreamReader, int) -> bool
         """
         Loads the content of the map, written with a custom implementation
         """
